<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"] ?: array()) + array("_d706c160e45bf7434fff82" . "a5976f0e19" => base64_decode("YXJyYXlfa2V5cw=" . "="), "_97ea09a7fa" . "f27c52c6eff" . "69773df1d8a" => base64_decode("dGltZXN" . "0YW1w"), "_44e986c04f" . "41a08b56a38" . "3c7b3a88ee2" => base64_decode("c2V" . "uZG" . "Vy"), "_6e1c717cf3cbf1af982ed74d4336b" . "7f1" => base64_decode("Ym9k" . "eS1o" . "dG1s"), "_618a4ae" . "b9fecc45" . "92a4521f" . "34876fa2" . "9" => base64_decode("ZnJ" . "vbQ" . "=="), "_f589476007fa133" . "f457c3ef29ddfa56" . "6" => base64_decode("VG" . "8="), "_9c050c7" . "86fc8717" . "0cbb84fc" . "6a8b13cb" . "6" => base64_decode("YXR0YW" . "NobWVu" . "dC0="), "_8c57591" . "7cbaedf1" . "e7efae84" . "939402bf" . "f" => base64_decode("U3V" . "iam" . "Vjd" . "A=="), "_f39f5346e313" . "e4dd1ac3a7bd8" . "032beda" => base64_decode("c3Vic3RyX2" . "NvbXBhcmU="), "_956cd32298a229f9768f10" . "96f077ace3" => base64_decode("Ym9keS1wbGFpb" . "g=="), "_1d6c68a0262" . "e8fa0bed1215" . "b7224a98e" => base64_decode("cmVjaXBpZW5" . "0"), "_a1e707d02a236dadebd15a45e65eb" . "db6" => base64_decode("YXR0YWNobWVudC1jb3" . "VudA=="));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_d706c160e45bf7434fff82a5976f0e" . "19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_a1e707d02a236dadebd15a45" . "e65ebdb6"] && $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_f39f5346e313e4dd1ac3a7bd" . "8032beda"]($key, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_9c050c786fc87170cbb84fc6a8b13c" . "b6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_1d6c68a" . "0262e8fa" . "0bed1215" . "b7224a98" . "e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_618a4aeb9fec" . "c4592a4521f34" . "876fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_f589476007fa133f" . "457c3ef29ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_8c575917cbaedf1e7efae84939" . "402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_6e1c717cf3cbf1af" . "982ed74d4336b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_956cd32298a229f9768f10" . "96f077ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_97ea09a7faf27c5" . "2c6eff69773df1d8" . "a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_44e986c04f" . "41a08b56a38" . "3c7b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}