<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"] ?: array()) + array("_618a4aeb9fecc4592a4521f348" . "76fa29" => base64_decode("ZnJvbQ" . "=="), "_9b16fa2683095e67d7c8b265a8081d" . "0b" => base64_decode("TWFpbFJlY2" . "VpdmVkRXZl" . "bnRSZWNlaX" . "Zlcg=="), "_03b1f0cee835582d1" . "158dce2678b505c" => base64_decode("U3RhcnRpbmcgaW5" . "mb2NhcHR1cmUgbW" . "FpbCByZWNlaXZlZ" . "CBzdWJzY3JpYmVy"), "_f656816961e85738" . "06141c558b184fe2" => base64_decode("c3Via" . "mVjdA" . "=="), "_ced92d7b391285c8a" . "26846f1f4bd3128" => base64_decode("Ym9keV" . "90ZXh0"), "_a3d82c5d" . "f38e194c9" . "c73e3ccb4" . "223bbc" => base64_decode("ZW1haW" . "xfZGF0" . "YQ=="), "project_" . "id" => base64_decode("cHJvamVj" . "dF9pZA=="), "_bfda889b74ea561b14325e30e" . "7d75426" => base64_decode("Ym9keV9od" . "G1s"), "_460e1aeb3113a" . "1676ce59a8f404" . "31d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9yIGluZm9jYXB0dXJlIHB" . "yb2plY3Q="), "_e608e5b5c4c34a67ba97ef84c1e" . "16199" => base64_decode("Jw=" . "="), "_c35473364fa7a" . "050299058f332e" . "c29c1" => base64_decode("ZXh" . "jZX" . "B0a" . "W9u"), "_376d30c40857357a4d4cbb1ff" . "aa25817" => base64_decode("d" . "G" . "8" . "="), "_67a0d624aebc" . "ceb0abd5ce56a" . "53ff06f" => base64_decode("ZGF0" . "ZQ=="), "_5d40a2cf1c525fb" . "252bf5599e339fdd" . "0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMgaWRlbnRp" . "ZmllZCBmb3IgbWFpbDsgc3ViamVjdCAn"));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_9b16fa2683095e67d7c8b" . "265a8081d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_03b1f0cee835582d1158dce2678" . "b505c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_5d40a2cf1c525fb25" . "2bf5599e339fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_e608e5b5c4c34a67ba97ef84" . "c1e16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_618a4aeb9fecc4592a4521f34876fa2" . "9"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_376d30c408" . "57357a4d4cb" . "b1ffaa25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_f656816961" . "e8573806141" . "c558b184fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_ced92d7b391285c8a26846f1f4bd3" . "128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_bfda889b74ea561b14325e30e" . "7d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_67a0d624aebcceb0a" . "bd5ce56a53ff06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_460e1aeb3113a1676" . "ce59a8f40431d5c"], [$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["project_i" . "d"] => $project->GetId(), $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_a3d82c5df38e194c9c73e3ccb" . "4223bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_c35473364fa7a050299058f332" . "ec29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}